# icamix

icamix is a Python package for mixing image amplitude.

## Installation

You can install the `icamix` package via pip:

pip install icamix

## Usage

import icamix

# Use functions from icamix
mixed_image = icamix.mix(x, y, num_class, lamb)